@@ -1,6 +1,8 @@
 from typing import Protocol
 from . import game
+from . import team
 
 class NCAABlike(Protocol):
 
-    games : game.gameslike.Gameslike
\ No newline at end of file
+    games : game.gameslike.Gameslike
+    teams : team.teamlike.TeamsByIdlike
\ No newline at end of file
