@@ -2,7 +2,11 @@ import datetime
 from . import efficiencylike
 
 class Efficiency(efficiencylike.Efficiencylike):
+    
     division : efficiencylike.Divisionalog
+    avg_oeff : float
+    avg_deff : float
+    ppp : float
 
     def __init__(self, division: efficiencylike.Divisionalog):
         self.division = division
@@ -14,4 +18,4 @@ class Efficiency(efficiencylike.Efficiencylike):
             date (datetime.datetime): the date on which the games take place.
         """
         for game in self.division.get_games_on_date(date):
-            game.home.biupdate_and_serialize(game.away, game.home_pts, game.away_pts)
+            game.home.biupdate_and_serialize(game.away, game.home_pts, game.away_pts, date)
