@@ -7,7 +7,7 @@ class Teamalog(Protocol):
     id : int
 
     @abc.abstractmethod
-    def biupdate_and_serialize(self, opponent : 'Teamalog', pppf : float, pppa : float, recency : float = .2)->None:
+    def biupdate_and_serialize(self, opponent : 'Teamalog', pppf : float, pppa : float, date : datetime.datetime, recency : float = .2)->None:
         pass
 
 class Gamealog(Protocol):
@@ -17,6 +17,7 @@ class Gamealog(Protocol):
     away_pts : float
 
 class Divisionalog(Protocol):
+    
     @abc.abstractmethod
     def get_games_on_date(self, date : datetime.datetime)->Sequence[Gamealog]:
         pass
@@ -24,6 +25,9 @@ class Divisionalog(Protocol):
 class Efficiencylike(Protocol):
 
     division : Divisionalog
+    avg_oeff : float
+    avg_deff : float
+    ppp : float
     
     @abc.abstractmethod
     def __init__(self, division : Divisionalog):
